@@ -5,6 +5,8 @@ from rich.console import Console
 from rich.markdown import Markdown
 from rich.panel import Panel
 from rich.live import Live
+from rich.syntax import Syntax
+from rich.columns import Columns
 import os
 import json
 import sys
@@ -33,6 +35,7 @@ class GPTerminator:
             "pconf": [None, "prints out the users current config file"],
             "setconf": [None, "switches to a new config"],
             "regen": ["r", "generates a new response from the last message"],
+            "new": ["n", "removes chat history and starts a new session"],
             "load": ["l", "loads a previously saved chatlog"],
             "save": ["s", "saves the chat history"],
             "ifile": [None, "allows the user to analyze files with a prompt"],
@@ -97,17 +100,21 @@ class GPTerminator:
         while True:
             try:
                 code_block = last_resp.split("```")[index]
+                lexer = code_block.split("\n")[0]
                 code_block = "\n".join(code_block.split("\n")[1:])
                 code_block_list.append(code_block)
             except:
                 lst_len = len(code_block_list)
                 if lst_len == 1:
                     pyperclip.copy(code_block_list[0])
+                    self.console.print(f"[bright_black]Copied text to keyboard...[/]")
                 elif lst_len > 1:
+                    choice_list = []
                     for num, code_block in enumerate(code_block_list):
-                        self.console.log(
-                            Panel.fit(code_block, title=f"Option {num + 1}")
-                        )
+                        code_block = Syntax(code_block, lexer)
+                        choice = Panel(code_block, title=f"[bright_black]Option[/] [red]{num + 1}[/]", border_style="bright_black", style="bold")
+                        choice_list.append(choice)
+                    self.console.print(Columns(choice_list))
                     while True:
                         self.console.print(
                             f"[yellow]|{self.cmd_init}|[/][bold green] Which code block do you want [/bold green][bold gray]> [/bold gray]",
@@ -121,6 +128,7 @@ class GPTerminator:
                             pass
                         self.printError("incorrect input, try again")
                     pyperclip.copy(code_block_list[idx - 1])
+                    self.console.print(f"[bright_black]Copied text to keyboard...[/]")
                 else:
                     self.printError("could not find code in previous response")
                 return
@@ -328,6 +336,10 @@ class GPTerminator:
                     self.useDalle()
                 elif cmd == "ifile":
                     self.analyzeFile()
+                elif cmd == "new" or cmd == "n":
+                    self.msg_hist = self.msg_hist[:1]
+                    self.prompt_count = 0
+                    self.printBanner()
             else:
                 self.printError(
                     f"{self.cmd_init}{cmd} in not in the list of commands, type {self.cmd_init}help"
@@ -423,6 +435,7 @@ class GPTerminator:
 |_____|__|    |_| |___|_| |_|_|_|_|_|_|__,|_| |___|_|  
 """
         self.console.print(f"[bold green]{welcome_ascii}[/bold green]", end="")
+        self.console.print(f"[bright_black]Version: v0.1.10[/]")
         self.console.print(f"[bright_black]System prompt: {self.sys_prmpt}[/]")
         self.console.print(f"[bright_black]Model: {self.model}[/]")
         self.console.print(
